==> irtorch-0.1.1.tar.gz: irtorch-0.1.1/README.md <==
[![tests](https://github.com/joakimwallmark/irtorch/actions/workflows/tests.yml/badge.svg)](https://github.com/joakimwallmark/irtorch/actions/workflows/tests.yml)
[![codecov](https://codecov.io/github/joakimwallmark/irtorch/graph/badge.svg?token=0TPDVGIUZ2)](https://codecov.io/github/joakimwallmark/irtorch)
[![Documentation Status](https://readthedocs.org/projects/irtorch/badge/?version=latest)](https://irtorch.readthedocs.io/en/latest/?badge=latest)

<img src="https://raw.githubusercontent.com/joakimwallmark/irtorch/main/docs/source/_static/logo_readme.png" alt="IRTorch" style="width: 50%;">

`IRTorch` is a Python package for item response theory (IRT). It utilizes [PyTorch](https://pytorch.org/) for model optimization and GPU support.
Check out our [documentation page](https://irtorch.readthedocs.io/en/latest/) for usage examples and API reference.

## Installation
Install from [Python Package Index (PyPI)](https://pypi.org/project/irtorch/)
```bash
pip install irtorch
```

Install from [GitHub](https://github.com/joakimwallmark/irtorch)
```bash
pip install git+https://github.com/joakimwallmark/irtorch.git
```

## Citation
Citations hold great value to us since they allow us to explore the various ways the software is being used. Additionally, citations serve as proof of usage, which can assist in securing grant funding.

To cite IRTorch in publications use:

Wallmark, J. (2024). IRTorch: Item response theory with Python (Version X.X) [Software]. GitHub. https://github.com/joakimwallmark/irtorch

Or use the following BibTeX entry:

```bibtex
@manual{irtorch,
  title = {{IRTorch}: Item response theory with Python},
  author = {Wallmark, Joakim},
  year = {2024},
  note = {Version X.X},
  url = {https://github.com/joakimwallmark/irtorch}
}
```

==> irtorch-0.2.0.tar.gz: irtorch-0.2.0/README.md <==
[![tests](https://github.com/joakimwallmark/irtorch/actions/workflows/tests.yml/badge.svg)](https://github.com/joakimwallmark/irtorch/actions/workflows/tests.yml)
[![codecov](https://codecov.io/github/joakimwallmark/irtorch/graph/badge.svg?token=0TPDVGIUZ2)](https://codecov.io/github/joakimwallmark/irtorch)
[![Documentation Status](https://readthedocs.org/projects/irtorch/badge/?version=latest)](https://irtorch.readthedocs.io/en/latest/?badge=latest)

<img src="https://raw.githubusercontent.com/joakimwallmark/irtorch/main/docs/source/_static/logo_readme.png" alt="IRTorch" style="width: 50%;">

`IRTorch` is a Python package for item response theory (IRT). It utilizes [PyTorch](https://pytorch.org/) for model optimization and GPU support.
Check out our [documentation page](https://irtorch.readthedocs.io/en/latest/) for usage examples and API reference.

## Installation
Install from [Python Package Index (PyPI)](https://pypi.org/project/irtorch/)
```bash
pip install irtorch
```

Install from [GitHub](https://github.com/joakimwallmark/irtorch)
```bash
pip install git+https://github.com/joakimwallmark/irtorch.git
```

## Citation
Citations hold great value to us since they allow us to explore the various ways the software is being used. Additionally, citations serve as proof of usage, which can assist in securing grant funding.

To cite IRTorch in publications use:

Wallmark, J. (2024). IRTorch: Item response theory with Python (Version X.X) https://github.com/joakimwallmark/irtorch

Or use the following BibTeX entry:

```bibtex
@manual{irtorch,
  title = {{IRTorch}: Item response theory with Python},
  author = {Wallmark, Joakim},
  year = {2024},
  note = {Version X.X},
  url = {https://github.com/joakimwallmark/irtorch}
}
```
